@@ -1,9 +1,10 @@
 from office365.runtime.client_object_collection import ClientObjectCollection
 from office365.runtime.queries.create_entity_query import CreateEntityQuery
-from office365.runtime.resource_path import ResourcePath
+from office365.runtime.paths.resource_path import ResourcePath
 
 
 class EntityCollection(ClientObjectCollection):
+    """Microsoft Graph entity set"""
 
     def __getitem__(self, key):
         """
@@ -17,17 +18,19 @@ class EntityCollection(ClientObjectCollection):
             return super(EntityCollection, self).__getitem__(key)
         return self._item_type(self.context, ResourcePath(key, self.resource_path))
 
-    def add_from_json(self, json):
-        """Creates a Entity resource from JSON
+    def new(self, **kwargs):
+        return self.create_typed_object(properties=kwargs, persist_changes=True)
+
+    def add(self, **kwargs):
+        """Creates a resource
 
-        :type json: dict
         :rtype: office365.entity.Entity
         """
-        entity = self._item_type(self.context)
-        self.add_child(entity)
-        qry = CreateEntityQuery(self, json, entity)
+        return_type = self.new(**kwargs)
+        self.add_child(return_type)
+        qry = CreateEntityQuery(self, return_type, return_type)
         self.context.add_query(qry)
-        return entity
+        return return_type
 
     @property
     def context(self):
@@ -35,3 +38,17 @@ class EntityCollection(ClientObjectCollection):
         :rtype: office365.graph_client.GraphClient
         """
         return self._context
+
+
+class DeltaCollection(EntityCollection):
+
+    @property
+    def delta(self):
+        """
+        Get newly created, updated, or deleted entities (changes)
+
+        :rtype: DeltaCollection
+        """
+        return self.get_property('delta',
+                                 DeltaCollection(self.context, self._item_type,
+                                                 ResourcePath("delta", self.resource_path)))
