@@ -1,27 +1,28 @@
+from office365.communications.cloud_communications import CloudCommunications
 from office365.directory.applications.application import Application
 from office365.directory.applications.application_template import ApplicationTemplate
+from office365.directory.applications.service_principal import ServicePrincipal
 from office365.directory.audit.audit_log_root import AuditLogRoot
 from office365.directory.directory import Directory
 from office365.directory.directory_object_collection import DirectoryObjectCollection
+from office365.directory.groups.group_collection import GroupCollection
 from office365.directory.groups.group_lifecycle_policy import GroupLifecyclePolicy
 from office365.directory.groups.group_setting_template import GroupSettingTemplate
-from office365.directory.groups.group_collection import GroupCollection
 from office365.directory.identities.identity_container import IdentityContainer
 from office365.directory.identities.identity_provider import IdentityProvider
+from office365.directory.licenses.subscribed_sku import SubscribedSku
 from office365.directory.organizations.org_contact import OrgContact
 from office365.directory.organizations.organization import Organization
-from office365.directory.applications.service_principal import ServicePrincipal
-from office365.directory.licenses.subscribed_sku import SubscribedSku
-from office365.outlook.calendar.place import Place
-from office365.reports.report_root import ReportRoot
 from office365.directory.subscriptions.subscription import Subscription
 from office365.directory.users.user import User
 from office365.directory.users.user_collection import UserCollection
-from office365.entity_collection import EntityCollection
+from office365.entity_collection import EntityCollection, DeltaCollection
 from office365.onedrive.drives.drive import Drive
 from office365.onedrive.shares.shares_collection import SharesCollection
 from office365.onedrive.sites.sites_with_root import SitesWithRoot
+from office365.outlook.calendar.place import Place
 from office365.planner.planner import Planner
+from office365.reports.report_root import ReportRoot
 from office365.runtime.auth.token_response import TokenResponse
 from office365.runtime.client_runtime_context import ClientRuntimeContext
 from office365.runtime.http.http_method import HttpMethod
@@ -29,13 +30,12 @@ from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.odata.odata_request import ODataRequest
 from office365.runtime.odata.v4.batch_request import ODataV4BatchRequest
 from office365.runtime.odata.v4.json_format import V4JsonFormat
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.queries.batch_query import BatchQuery
 from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
 from office365.runtime.queries.update_entity_query import UpdateEntityQuery
-from office365.runtime.resource_path import ResourcePath
 from office365.search.search_entity import SearchEntity
 from office365.teams.chats.chat import Chat
-from office365.communications.cloud_communications import CloudCommunications
 from office365.teams.team_collection import TeamCollection
 from office365.teams.teams_template import TeamsTemplate
 
@@ -55,18 +55,18 @@ class GraphClient(ClientRuntimeContext):
         self._authority_host_url = "https://login.microsoftonline.com"
         self._acquire_token_callback = acquire_token_callback
 
-    def build_single_request(self, query):
+    def build_request(self, query):
         """
         :type: office365.runtime.queries.client_query.ClientQuery
         """
-        request = super(GraphClient, self).build_single_request(query)
+        request = super(GraphClient, self).build_request(query)
         self._build_specific_query(request)
         return request
 
     def execute_batch(self):
         """Construct and submit a batch request"""
         batch_request = ODataV4BatchRequest(self)
-        queries = [qry for qry in self.pending_request().next_query()]
+        queries = [qry for qry in self.pending_request()]
         batch_request.add_query(BatchQuery(self, queries))  # Aggregate requests into batch request
         batch_request.execute_query()
 
@@ -151,7 +151,7 @@ class GraphClient(ClientRuntimeContext):
     @property
     def contacts(self):
         """Get the list of organizational contacts for this organization."""
-        return EntityCollection(self, OrgContact, ResourcePath("contacts"))
+        return DeltaCollection(self, OrgContact, ResourcePath("contacts"))
 
     @property
     def directory(self):
@@ -174,12 +174,12 @@ class GraphClient(ClientRuntimeContext):
     @property
     def applications(self):
         """Get the list of applications in this organization."""
-        return EntityCollection(self, Application, ResourcePath("applications"))
+        return DeltaCollection(self, Application, ResourcePath("applications"))
 
     @property
     def service_principals(self):
         """Retrieve a list of servicePrincipal objects."""
-        return EntityCollection(self, ServicePrincipal, ResourcePath("servicePrincipals"))
+        return DeltaCollection(self, ServicePrincipal, ResourcePath("servicePrincipals"))
 
     @property
     def organization(self):
