@@ -13,7 +13,7 @@ class ClientObject(object):
         Base client object which define named properties and relationships of an entity
 
         :type parent_collection: office365.runtime.client_object_collection.ClientObjectCollection or None
-        :type resource_path: office365.runtime.resource_path.ResourcePath or None
+        :type resource_path: office365.runtime.client_path.ClientPath or None
         :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
         :type namespace: str
         """
@@ -52,7 +52,7 @@ class ClientObject(object):
         return self
 
     def build_request(self):
-        return self.context.build_request()
+        return self.context.build_request(self.context.current_query)
 
     def get(self):
         self.context.load(self)
@@ -169,16 +169,11 @@ class ClientObject(object):
 
     @property
     def resource_url(self):
-        """Generate resource Url
-
+        """
+        Returns resource url
         :rtype: str or None
         """
-        if self.resource_path:
-            url = self.context.service_root_url() + self.resource_path.to_url()
-            if not self.query_options.is_empty:
-                url = url + "?" + self._query_options.to_url()
-            return url
-        return None
+        return self.context.service_root_url() + str(self.resource_path)
 
     @property
     def context(self):
@@ -213,6 +208,6 @@ class ClientObject(object):
         if json and self.entity_type_name is not None:
             if isinstance(json_format, JsonLightFormat) and json_format.is_verbose:
                 json[json_format.metadata_type_tag_name] = {'type': self.entity_type_name}
-            elif isinstance(json_format, ODataJsonFormat) and json_format.metadata == "minimal":
+            elif isinstance(json_format, ODataJsonFormat) and json_format.metadata_level == "minimal":
                 json[json_format.metadata_type_tag_name] = "#" + self.entity_type_name
         return json
