@@ -2,22 +2,21 @@ import abc
 from time import sleep
 
 from office365.runtime.client_request_exception import ClientRequestException
+from office365.runtime.client_result import ClientResult
 from office365.runtime.compat import is_absolute_url
+from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
+from office365.runtime.queries.client_query import ClientQuery
 from office365.runtime.queries.read_entity_query import ReadEntityQuery
 
 
 class ClientRuntimeContext(object):
 
-    def build_request(self):
-        return self.pending_request().build_request()
-
-    def build_single_request(self, query):
+    def build_request(self, query):
         """
-
-        :type: office365.runtime.queries.client_query.ClientQuery
+        :type query: office365.runtime.queries.client_query.ClientQuery
         """
-        return self.pending_request().build_single_request(query)
+        return self.pending_request().build_request(query)
 
     def execute_query_retry(self, max_retry=5, timeout_secs=5, success_callback=None, failure_callback=None,
                             exceptions=(ClientRequestException,)):
@@ -39,9 +38,9 @@ class ClientRuntimeContext(object):
                 break
             except exceptions as e:
                 self.add_query(self.current_query, True)
-                sleep(timeout_secs)
                 if callable(failure_callback):
                     failure_callback(retry, e)
+                sleep(timeout_secs)
 
     @abc.abstractmethod
     def pending_request(self):
@@ -52,6 +51,9 @@ class ClientRuntimeContext(object):
 
     @abc.abstractmethod
     def service_root_url(self):
+        """
+        :rtype: str
+        """
         pass
 
     @abc.abstractmethod
@@ -139,8 +141,31 @@ class ClientRuntimeContext(object):
         """
         self.pending_request().add_query(query, execute_first, set_as_current)
 
-    def clear_queries(self):
-        self.pending_request().queries.clear()
+    def clear(self):
+        self.pending_request().clear()
+
+    def get_metadata(self):
+        result = ClientResult(self)
+
+        def _construct_download_request(request):
+            """
+            :type request: office365.runtime.http.request_options.RequestOptions
+            """
+            request.url += "/$metadata"
+            request.method = HttpMethod.Get
+
+        def _process_download_response(response):
+            """
+            :type response: requests.Response
+            """
+            response.raise_for_status()
+            result.value = response.content
+
+        qry = ClientQuery(self)
+        self.before_execute(_construct_download_request)
+        self.after_execute(_process_download_response)
+        self.add_query(qry)
+        return qry
 
     @property
     def current_query(self):
