@@ -35,10 +35,13 @@ class ODataRequest(ClientRequest):
         self.ensure_media_type(request)
         return super(ODataRequest, self).execute_request_direct(request)
 
-    def build_request(self):
-        query = self.context.current_query
-        action_url = query.build_url()
-        request = RequestOptions(action_url)
+    def build_request(self, query):
+        """
+        :type query: office365.runtime.queries.client_query.ClientQuery
+        """
+        self._current_query = query
+
+        request = RequestOptions(query.url)
         self.ensure_media_type(request)
         # set method
         request.method = HttpMethod.Get
@@ -76,13 +79,12 @@ class ODataRequest(ClientRequest):
         else:
             if isinstance(query, ServiceOperationQuery):
                 self.json_format.function_tag_name = query.method_name
-            else:
-                self.json_format.function_tag_name = None
 
             if isinstance(return_type, ClientResult):
                 if isinstance(return_type.value, ClientValue) or isinstance(return_type.value, ClientObject):
                     return_type = return_type.value
             self.map_json(response.json(), return_type, self.json_format)
+            self.json_format.function_tag_name = None
 
     def map_json(self, json, return_type, json_format=None):
         """
