@@ -5,5 +5,5 @@ from office365.sharepoint.fields.field_user_value import FieldUserValue
 class FieldMultiUserValue(FieldMultiLookupValue):
 
     def __init__(self):
-        super().__init__()
+        super(FieldMultiUserValue, self).__init__()
         self._item_type = FieldUserValue
