@@ -1,8 +1,8 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
-from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
+from office365.runtime.paths.resource_path import ResourcePath
+from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.changes.change_collection import ChangeCollection
 from office365.sharepoint.changes.change_query import ChangeQuery
@@ -30,7 +30,7 @@ class ListItem(SecurableObject):
         """
 
         :type context: office365.sharepoint.client_context.ClientContext
-        :type resource_path: ResourcePath or None
+        :type resource_path: office365.runtime.client_path.ClientPath or None
         :type parent_list: office365.sharepoint.lists.list.List or None
         """
         super(ListItem, self).__init__(context, resource_path)
@@ -350,7 +350,7 @@ class ListItem(SecurableObject):
         # fallback: create a new resource path
         if self._resource_path is None:
             if name == "Id" and self._parent_collection is not None:
-                self._resource_path = ResourcePathServiceOperation(
+                self._resource_path = ServiceOperationPath(
                     "getItemById", [value], self._parent_collection.resource_path.parent)
         return self
 
