@@ -1,11 +1,11 @@
-from office365.runtime.client_object_collection import ClientObjectCollection
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
-from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
+from office365.runtime.paths.resource_path import ResourcePath
+from office365.runtime.paths.service_operation import ServiceOperationPath
+from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.permissions.role_assignment import RoleAssignment
 
 
-class RoleAssignmentCollection(ClientObjectCollection):
+class RoleAssignmentCollection(BaseEntityCollection):
     """Represents a collection of RoleAssignment resources."""
 
     def __init__(self, context, resource_path=None):
@@ -26,9 +26,9 @@ class RoleAssignmentCollection(ClientObjectCollection):
         :param int principal_id: Specifies the user or group of the role assignment.
         """
         role_assignment = RoleAssignment(self.context,
-                                         ResourcePathServiceOperation("GetByPrincipalId",
-                                                                      [principal_id],
-                                                                      self.resource_path))
+                                         ServiceOperationPath("GetByPrincipalId",
+                                                              [principal_id],
+                                                              self.resource_path))
         self.context.load(role_assignment)
         return role_assignment
 
