@@ -1,6 +1,6 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.permissions.base_permissions import BasePermissions
 from office365.sharepoint.permissions.role_assignment import RoleAssignment
@@ -17,7 +17,7 @@ class SecurableObject(BaseEntity):
         :param office365.sharepoint.principal.principal.Principal principal: Specifies the user or group of the
             role assignment.
 
-        :return: RoleAssignment
+        :rtype: RoleAssignment
         """
         result = ClientResult(self.context, RoleAssignment(self.context))
 
