@@ -2,7 +2,7 @@ from office365.runtime.client_object import ClientObject
 from office365.runtime.client_result import ClientResult
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.portal.group_creation_params import GroupCreationInformation
 from office365.sharepoint.portal.group_site_info import GroupSiteInfo
 
