@@ -1,7 +1,7 @@
 from office365.runtime.client_runtime_context import ClientRuntimeContext
 from office365.runtime.odata.odata_request import ODataRequest
-from office365.runtime.odata.v4_json_format import V4JsonFormat
-from office365.runtime.resource_path import ResourcePath
+from office365.runtime.odata.v4.json_format import V4JsonFormat
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.taxonomy.term_store import TermStore
 
 
@@ -15,7 +15,7 @@ class TaxonomyService(ClientRuntimeContext):
         super(TaxonomyService, self).__init__()
         self._auth_context = context.authentication_context
         self._pendingRequest = ODataRequest(self, V4JsonFormat("minimal"))
-        self._service_root_url = "{0}v2.1/".format(context.service_root_url())
+        self._service_root_url = "{0}/v2.1/".format(context.service_root_url())
 
     def authenticate_request(self, request):
         self._auth_context.authenticate_request(request)
