@@ -2,7 +2,8 @@ from office365.runtime.client_object import ClientObject
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
+from office365.runtime.queries.update_entity_query import UpdateEntityQuery
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.publishing.portal_health_status import PortalHealthStatus
 from office365.sharepoint.tenant.administration.hubsite_properties import HubSiteProperties
 from office365.sharepoint.tenant.administration.secondary_administrators_fields_data import \
@@ -15,11 +16,21 @@ from office365.sharepoint.tenant.administration.spo_operation import SpoOperatio
 
 
 class Tenant(ClientObject):
+    """Represents a SharePoint tenant."""
 
     def __init__(self, context):
-        super(Tenant, self).__init__(context, ResourcePath("Microsoft.Online.SharePoint.TenantAdministration.Tenant"),
-                                     None,
-                                     "Microsoft.Online.SharePoint.TenantAdministration")
+        super(Tenant, self).__init__(
+            context,
+            ResourcePath("Microsoft.Online.SharePoint.TenantAdministration.Tenant"),
+            None,
+            "Microsoft.Online.SharePoint.TenantAdministration"
+            )
+
+    def update(self):
+        """Update Tenant settings"""
+        qry = UpdateEntityQuery(self)
+        self.context.add_query(qry)
+        return self
 
     @staticmethod
     def from_url(admin_site_url):
@@ -33,7 +44,7 @@ class Tenant(ClientObject):
     def get_lock_state_by_id(self, site_id):
         return self._sites.get_lock_state_by_id(site_id)
 
-    def hub_sites(self, siteUrl):
+    def hub_sites(self, site_url):
         pass
 
     def check_tenant_licenses(self, licenses):
@@ -99,14 +110,14 @@ class Tenant(ClientObject):
         self.context.add_query(qry)
         return return_type
 
-    def unregister_hub_site(self, siteUrl):
+    def unregister_hub_site(self, site_url):
         """
         Unregisters a hub site so that it is no longer a hub site.
 
-        :param str siteUrl:
+        :param str site_url:
         :return:
         """
-        params = {"siteUrl": siteUrl}
+        params = {"siteUrl": site_url}
         qry = ServiceOperationQuery(self, "UnregisterHubSite", None, params, None, None)
         self.context.add_query(qry)
         return self
