@@ -2,8 +2,8 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
-from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
+from office365.runtime.paths.resource_path import ResourcePath
+from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.alerts.alert_collection import AlertCollection
 from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.changes.change_collection import ChangeCollection
@@ -54,6 +54,7 @@ class Web(SecurableObject):
 
     def __init__(self, context, resource_path=None):
         """
+        Specifies the push notification subscriber over the site for the specified device app instance identifier.
 
         :type resource_path: ResourcePath or None
         :type context: office365.sharepoint.client_context.ClientContext
@@ -88,6 +89,7 @@ class Web(SecurableObject):
 
     def get_push_notification_subscribers_by_user(self, user_or_username):
         """
+        Queries for the push notification subscribers for the site  for the specified user.
 
         :param str or User user_or_username:
         """
@@ -108,11 +110,13 @@ class Web(SecurableObject):
 
     @staticmethod
     def create_organization_sharing_link(context, url, is_edit_link):
-        """
+        """ Creates and returns an organization-internal link that can be used to access a document and gain permissions
+           to it.
 
         :param office365.sharepoint.client_context.ClientContext context:
-        :param str url:
-        :param bool is_edit_link:
+        :param str url: he URL of the site, with the path of the object in SharePoint that is represented as query
+            string parameters, forSharing set to 1 if sharing, and mbypass set to 1 to bypass any mobile logic.
+        :param bool is_edit_link: If true, the link will allow the logged in user to edit privileges on the item.
         """
         result = ClientResult(context)
         params = {"url": url, "isEditLink": is_edit_link}
@@ -136,10 +140,10 @@ class Web(SecurableObject):
 
     @staticmethod
     def get_web_url_from_page_url(context, page_full_url):
-        """Gets Web from page url
+        """Returns the URL of the root folder for the site containing the specified URL
 
         :type context: office365.sharepoint.client_context.ClientContext
-        :type page_full_url: str
+        :param str page_full_url: Specifies the URL from which to return the site URL.
         """
         result = ClientResult(context)
         payload = {
@@ -189,6 +193,11 @@ class Web(SecurableObject):
         return result
 
     def get_client_side_web_parts(self, project, include_errors=False):
+        """
+        :param str project:
+        :param bool include_errors: If true, webparts with errors MUST be included in the results of the request.
+           If false, webparts with errors MUST be excluded in the results of the request.
+        """
         result = ClientValueCollection(SPClientSideComponentQueryResult)
         params = {
             "includeErrors": include_errors,
@@ -242,25 +251,25 @@ class Web(SecurableObject):
     def get_all_webs(self):
         """Returns a collection containing a flat list of all Web objects in the Web."""
         from office365.sharepoint.webs.web_collection import WebCollection
-        result = ClientResult(self.context, WebCollection(self.context, self.webs.resource_path))
+        return_type = WebCollection(self.context, self.webs.resource_path)
 
         def _webs_loaded():
-            self._load_sub_webs_inner(self.webs, result)
+            self._load_sub_webs_inner(self.webs, return_type)
 
         self.ensure_property("Webs", _webs_loaded)
-        return result
+        return return_type
 
-    def _load_sub_webs_inner(self, webs, result):
+    def _load_sub_webs_inner(self, webs, all_webs):
         """
         :type webs: office365.sharepoint.webs.web_collection.WebCollection
-        :type result: ClientResult
+        :type all_webs: office365.sharepoint.webs.web_collection.WebCollection
         """
         for cur_web in webs:  # type: Web
-            result.value.add_child(cur_web)
+            all_webs.add_child(cur_web)
 
             def _webs_loaded(web):
                 if len(web.webs) > 0:
-                    self._load_sub_webs_inner(web.webs, result)
+                    self._load_sub_webs_inner(web.webs, all_webs)
 
             cur_web.ensure_property("Webs", _webs_loaded, cur_web)
 
@@ -359,7 +368,7 @@ class Web(SecurableObject):
         """
         return File(
             self.context,
-            ResourcePathServiceOperation("getFileByServerRelativeUrl", [url], self.resource_path)
+            ServiceOperationPath("getFileByServerRelativeUrl", [url], self.resource_path)
         )
 
     def get_file_by_server_relative_path(self, decoded_url):
@@ -370,7 +379,7 @@ class Web(SecurableObject):
         """
         return File(
             self.context,
-            ResourcePathServiceOperation("getFileByServerRelativePath", {"DecodedUrl": decoded_url}, self.resource_path)
+            ServiceOperationPath("getFileByServerRelativePath", {"DecodedUrl": decoded_url}, self.resource_path)
         )
 
     def get_folder_by_server_relative_url(self, url):
@@ -379,7 +388,7 @@ class Web(SecurableObject):
         """
         return Folder(
             self.context,
-            ResourcePathServiceOperation("getFolderByServerRelativeUrl", [url], self.resource_path)
+            ServiceOperationPath("getFolderByServerRelativeUrl", [url], self.resource_path)
         )
 
     def get_folder_by_server_relative_path(self, decoded_url):
@@ -392,7 +401,7 @@ class Web(SecurableObject):
         params = {"DecodedUrl": decoded_url}
         return Folder(
             self.context,
-            ResourcePathServiceOperation("getFolderByServerRelativePath", params, self.resource_path)
+            ServiceOperationPath("getFolderByServerRelativePath", params, self.resource_path)
         )
 
     def ensure_folder_path(self, path):
@@ -460,12 +469,12 @@ class Web(SecurableObject):
         :param int user_id: Specifies the member identifier.
         """
         return User(self.context,
-                    ResourcePathServiceOperation("getUserById", [user_id], self.resource_path))
+                    ServiceOperationPath("getUserById", [user_id], self.resource_path))
 
     def default_document_library(self):
         """Retrieves the default document library."""
         return List(self.context,
-                    ResourcePathServiceOperation("defaultDocumentLibrary", None, self.resource_path))
+                    ServiceOperationPath("defaultDocumentLibrary", None, self.resource_path))
 
     def get_list(self, url):
         """Get list by url
@@ -473,7 +482,7 @@ class Web(SecurableObject):
         :type url: str
         """
         return List(self.context,
-                    ResourcePathServiceOperation("getList", [url], self.resource_path))
+                    ServiceOperationPath("getList", [url], self.resource_path))
 
     def get_changes(self, query):
         """Returns the collection of all changes from the change log that have occurred within the scope of the site,
@@ -499,8 +508,8 @@ class Web(SecurableObject):
             "doIncludeCrossLanguage": do_include_cross_language
         }
         return_type = WebTemplateCollection(self.context,
-                                            ResourcePathServiceOperation("GetAvailableWebTemplates ", params,
-                                                                         self.resource_path))
+                                            ServiceOperationPath("GetAvailableWebTemplates ", params,
+                                                                 self.resource_path))
 
         qry = ServiceOperationQuery(self, "GetAvailableWebTemplates", params, None, None, return_type)
         self.context.add_query(qry)
@@ -529,7 +538,9 @@ class Web(SecurableObject):
 
     def get_file_by_guest_url(self, guest_url):
         """
-        :type guest_url: str
+        Returns the file object from the guest access URL.
+
+        :param str guest_url: The guest access URL to get the file with.
         """
         return_type = File(self.context)
         qry = ServiceOperationQuery(self, "GetFileByGuestUrl", [guest_url], None, None, return_type)
@@ -538,7 +549,9 @@ class Web(SecurableObject):
 
     def get_file_by_wopi_frame_url(self, wopi_frame_url):
         """
-        :param str wopi_frame_url:
+        Returns the file object from the WOPI frame URL.
+
+        :param str wopi_frame_url:  The WOPI frame URL used to get the file object.
         """
         return_type = File(self.context)
         qry = ServiceOperationQuery(self, "GetFileByWOPIFrameUrl", [wopi_frame_url], None, None, return_type)
@@ -547,7 +560,9 @@ class Web(SecurableObject):
 
     def get_folder_by_guest_url(self, guest_url):
         """
-        :type guest_url: str
+        Returns the folder object from the tokenized sharing link URL.
+
+        :param str guest_url: The tokenized sharing link URL for the folder.
         """
         return_type = File(self.context)
         qry = ServiceOperationQuery(self, "GetFolderByGuestUrl", [guest_url], None, None, return_type)
@@ -625,10 +640,13 @@ class Web(SecurableObject):
     @staticmethod
     def get_document_and_media_libraries(context, web_full_url, include_page_libraries):
         """
+        Returns the document libraries of a SharePoint site, including picture, asset, and site assets libraries.
+        Document libraries that are private, catalog library, application list, form template, or libraries that user
+        does not have permission to view items are not inlcuded.
 
-        :param office365.sharepoint.client_context.ClientContext context:
-        :param str web_full_url:
-        :param bool include_page_libraries:
+        :param office365.sharepoint.client_context.ClientContext context: SharePoint context
+        :param str web_full_url:  URL of the web.
+        :param bool include_page_libraries: Indicates whether to include page libraries. A value of "true" means yes.
         """
         result = ClientResult(context, ClientValueCollection(DocumentLibraryInformation))
         payload = {
@@ -665,6 +683,7 @@ class Web(SecurableObject):
     @staticmethod
     def get_sharing_link_kind(context, file_url):
         """
+        This method determines the kind of tokenized sharing link represented by the supplied file URL.
 
         :param office365.sharepoint.client_context.ClientContext context:
         :param str file_url:
@@ -679,8 +698,8 @@ class Web(SecurableObject):
     def share_object(context, url, people_picker_input,
                      role_value=None,
                      groupId=0, propagateAcl=False,
-                     sendEmail=True, includeAnonymousLinkInEmail=False, emailSubject=None, emailBody=None,
-                     useSimplifiedRoles=True):
+                     send_email=True, includeAnonymousLinkInEmail=False, email_subject=None, email_body=None,
+                     use_simplified_roles=True):
         """
         This method shares an object in SharePoint such as a list item or site. It returns a SharingResult object
         which contains the completion script and a page to redirect to if desired.
@@ -692,12 +711,12 @@ class Web(SecurableObject):
         :param str people_picker_input: A string of JSON representing users in people picker format.
         :param int groupId: The ID of the group to be added. Zero if not adding to a permissions group.
         :param bool propagateAcl:  A flag to determine if permissions SHOULD be pushed to items with unique permissions.
-        :param bool sendEmail: A flag to determine if an email notification SHOULD be sent (if email is configured).
+        :param bool send_email: A flag to determine if an email notification SHOULD be sent (if email is configured).
         :param bool includeAnonymousLinkInEmail: If an email is being sent, this determines if an anonymous link
         SHOULD be added to the message.
-        :param str emailSubject: The email subject.
-        :param str emailBody: The email subject.
-        :param bool useSimplifiedRoles: A Boolean value indicating whether to use the SharePoint simplified roles
+        :param str email_subject: The email subject.
+        :param str email_body: The email subject.
+        :param bool use_simplified_roles: A Boolean value indicating whether to use the SharePoint simplified roles
         (Edit, View) or not.
 
         """
@@ -709,10 +728,10 @@ class Web(SecurableObject):
             "roleValue": role_value,
             "includeAnonymousLinkInEmail": includeAnonymousLinkInEmail,
             "propagateAcl": propagateAcl,
-            "sendEmail": sendEmail,
-            "emailSubject": emailSubject,
-            "emailBody": emailBody,
-            "useSimplifiedRoles": useSimplifiedRoles
+            "sendEmail": send_email,
+            "emailSubject": email_subject,
+            "emailBody": email_body,
+            "useSimplifiedRoles": use_simplified_roles
         }
         qry = ServiceOperationQuery(context.web, "ShareObject", None, payload, None, result)
         qry.static = True
@@ -755,14 +774,14 @@ class Web(SecurableObject):
         for example, "/sites/MySite/Shared Documents/MyDocument.docx".
         :return: ListItem
         """
-        return ListItem(self.context, ResourcePathServiceOperation("GetListItem", [str_url], self.resource_path))
+        return ListItem(self.context, ServiceOperationPath("GetListItem", [str_url], self.resource_path))
 
     def get_catalog(self, type_catalog):
         """Gets the list template gallery, site template gallery, or Web Part gallery for the Web site.
 
         :param int type_catalog: The type of the gallery.
         """
-        return List(self.context, ResourcePathServiceOperation("getCatalog", [type_catalog], self.resource_path))
+        return List(self.context, ServiceOperationPath("getCatalog", [type_catalog], self.resource_path))
 
     def page_context_info(self, include_odb_settings, emit_navigation_info):
         """
@@ -1058,7 +1077,7 @@ class Web(SecurableObject):
 
     @property
     def resource_url(self):
-        url = super(Web, self).resource_url
+        val = super(Web, self).resource_url
         if self._web_url is not None:
-            url = url.replace(self.context.service_root_url(), self._web_url + '/_api/')
-        return url
+            val = val.replace(self.context.service_root_url(), self._web_url + '/_api')
+        return val
